==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/dlight.nativeexecution/test/unit/src/org/netbeans/modules/nativeexecution/support/ShellSessionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.nativeexecution.support;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.nativeexecution.api.util.ProcessUtils.ExitStatus;
import org.netbeans.modules.nativeexecution.test.NativeExecutionBaseTestCase;

/**
 *
 * @author Andrew
 */
public class ShellSessionTest extends NativeExecutionBaseTestCase {

    public ShellSessionTest(String name) {
        super(name);
    }

    @BeforeClass
    public static void setUpClass() {
    }

    @AfterClass
    public static void tearDownClass() {
    }

    @Before
    @Override
    public void setUp() {
    }

    @After
    @Override
    public void tearDown() {
    }

    /**
     * Test of execute method, of class ShellSession.
     */
    @Test
    public void testExecute() throws Exception {
        ExecutionEnvironment env = ExecutionEnvironmentFactory.getLocal();
        System.out.println("execute unknown-command");
        ExitStatus result1 = ShellSession.execute(env, "unknown-command");
        System.out.println("Result1 [expected]: rc != 0, error is not empty and output is empty");
        System.out.println("Result1 [actual]  : ====== START =====");
        System.out.println(result1.toString());
        System.out.println("Result1 [actual]  : ======= END ======");

        String command = "echo out; echo error 1>&2; sh -c \"exit 100\"";
        System.out.println();
        System.out.println("execute '" + command + "'");
        ExitStatus result2 = ShellSession.execute(env, command);
        System.out.println("Result2 [expected]: rc == 100, error is 'error' and output is 'out'");
        System.out.println("Result2 [actual]  : ====== START =====");
        System.out.println(result2.toString());
        System.out.println("Result2 [actual]  : ======= END ======");

        assertNotSame(0, result1.exitCode);
        assertNotSame("It is expected that error stream is empty", "", result1.error.isEmpty());

        assertEquals(100, result2.exitCode);
        assertEquals("out\n", result2.output);
        assertEquals("error\n", result2.error);
    }
}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/dlight.nativeexecution/test/unit/src/org/netbeans/modules/nativeexecution/support/ShellSessionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.nativeexecution.support;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.nativeexecution.api.util.ProcessUtils.ExitStatus;
import org.netbeans.modules.nativeexecution.test.NativeExecutionBaseTestCase;

/**
 *
 * @author Andrew
 */
public class ShellSessionTest extends NativeExecutionBaseTestCase {

    public ShellSessionTest(String name) {
        super(name);
    }

    @BeforeClass
    public static void setUpClass() {
    }

    @AfterClass
    public static void tearDownClass() {
    }

    @Before
    @Override
    public void setUp() {
    }

    @After
    @Override
    public void tearDown() {
    }

    /**
     * Test of execute method, of class ShellSession.
     */
    @Test
    public void testExecute() throws Exception {
        ExecutionEnvironment env = ExecutionEnvironmentFactory.getLocal();
        System.out.println("execute unknown-command");
        ExitStatus result1 = ShellSession.execute(env, "unknown-command");
        System.out.println("Result1 [expected]: rc != 0, error is not empty and output is empty");
        System.out.println("Result1 [actual]  : ====== START =====");
        System.out.println(result1.toString());
        System.out.println("Result1 [actual]  : ======= END ======");

        String command = "echo out; echo error 1>&2; sh -c \"exit 100\"";
        System.out.println();
        System.out.println("execute '" + command + "'");
        ExitStatus result2 = ShellSession.execute(env, command);
        System.out.println("Result2 [expected]: rc == 100, error is 'error' and output is 'out'");
        System.out.println("Result2 [actual]  : ====== START =====");
        System.out.println(result2.toString());
        System.out.println("Result2 [actual]  : ======= END ======");

        assertNotSame(0, result1.exitCode);
        assertNotSame("It is expected that error stream is empty", "", result1.getErrorString().isEmpty());

        assertEquals(100, result2.exitCode);
        assertEquals("out", result2.getOutputString());
        assertEquals("error", result2.getErrorString());
    }
}
